==> tecfy_core_package-1.0.14.tar.gz: lib/views/components/home/title_path.componenet.dart <==
part of tecfy_core_client_package;

class TitlePathComponenet extends StatefulWidget {
  final String title;
  TitlePathComponenet(this.title);
  @override
  _TitlePathComponenetState createState() => _TitlePathComponenetState();
}

class _TitlePathComponenetState extends AppState<TitlePathComponenet> {
  Map<int, String>? _titleLevels;
  int? _min;
  int? _max;
  // int _selectedOrderId;
  @override
  void initState() {
    super.initState();
    _fillData();
  }

  _fillData() {
    if (_titleLevels != null) return;
    _titleLevels = {};
    if (_findLabel(1, InitService.menuItems!)) {
      _min = _titleLevels!.keys.first;
      _max = _titleLevels!.keys.last;
    } else {
      _titleLevels = {0: widget.title};
      _min = 0;
      _max = 0;
    }
    // print('==============titleLevels================= ${widget.title}');
    // print(titleLevels);
    // print('===============================');
  }

  bool _findLabel(int level, List<MenuItem>? items) {
    if (items == null) return false;
    var isExist = items.any((e) => e.displayName == widget.title);
    if (!isExist) {
      for (var item in items) {
        _titleLevels![level] = item.displayName;
        if (_findLabel(level + 1, item.subMenuItems)) return true;
      }
    } else {
      _titleLevels![level] = widget.title;
      // _selectedOrderId =
      //     items.firstWhere((e) => e.displayName == widget.title).orderId;
      // print('---------------- Selected Hero is $_selectedOrderId');
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    //|| titleLevels.keys.length <= 1
    if (_titleLevels == null) return Container();
    return
        //  Hero(
        //                     transitionOnUserGestures: true,
        //                     tag: 'menuItem-${widget.title}', child:
        Row(
            children: _titleLevels!.keys.map((e) => _getText(e)).toList()
              ..insert(0,
                  Navigator.canPop(context) ? _getBackButton() : Container()));
  }

  Widget _getBackButton() {
    return IconButton(
        icon: Icon(Icons.arrow_back),
        tooltip: trans('Back'),
        onPressed: () {
          AppNavigator.pop(context);
        });
  }

  Widget _getText(int index) {
    Widget text = Text(
      _titleLevels![index] ?? '',
      style: TextStyle(
        color: index == _max
            ? ThemeService.textSubColor
            : ThemeService.secondryColor,
      ),
    );

    if (index != _max) {
      return Row(children: <Widget>[
        text,
        SizedBox(width: 3),
        Text('/', style: TextStyle(color: ThemeService.textSubColor)),
        SizedBox(width: 3),
      ]);
    }
    return text;
  }
}

==> tecfy_core_package-1.0.23.tar.gz: lib/views/components/home/title_path.componenet.dart <==
part of tecfy_core_client_package;

class TitlePathComponenet extends StatefulWidget {
  final String title;
  final String code;
  TitlePathComponenet(this.code, this.title);
  @override
  _TitlePathComponenetState createState() => _TitlePathComponenetState();
}

class _TitlePathComponenetState extends AppState<TitlePathComponenet> {
  Map<int, List<String>>? _titleLevels;
  int? _min;
  int? _max;
  // int _selectedOrderId;
  @override
  void initState() {
    super.initState();
    _fillData();
  }

  _fillData() {
    if (_titleLevels != null) return;
    _titleLevels = {};
    if (_findLabel(1, InitService.menuItems!)) {
      _min = _titleLevels!.keys.first;
      _max = _titleLevels!.keys.last;
    } else {
      _titleLevels = {
        0: [widget.code, widget.title]
      };
      _min = 0;
      _max = 0;
    }
    // print(
    //     '==============titleLevels================= ${widget.code} ${widget.title}');
    // print(_titleLevels);
    // print('===============================');
  }

  bool _findLabel(int level, List<MenuItem>? items) {
    if (items == null) return false;
    var isExist = items.any((e) => e.code == widget.code);
    if (!isExist) {
      for (var item in items) {
        _titleLevels![level] = [item.code, item.displayName];

        if (_findLabel(level + 1, item.subMenuItems)) return true;
      }
    } else {
      _titleLevels![level] = [widget.code, widget.title];

      // _selectedOrderId =
      //     items.firstWhere((e) => e.code == widget.title).orderId;
      // print('---------------- Selected Hero is $_selectedOrderId');
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    //|| titleLevels.keys.length <= 1
    if (_titleLevels == null)
      return Row(children: [
        Navigator.canPop(context) ? _getBackButton() : Container(),
        Text('N/A')
        // Text(
        //   _titleLevels![index]?[1] ?? '',
        //   style: TextStyle(
        //     color: index == _max
        //         ? ThemeService.textSubColor
        //         : ThemeService.secondryColor,
        //   ),
        // )
      ]);
    return
        //  Hero(
        //                     transitionOnUserGestures: true,
        //                     tag: 'menuItem-${widget.title}', child:
        Row(
            children: _titleLevels!.keys.map((e) => _getText(e)).toList()
              ..insert(0,
                  Navigator.canPop(context) ? _getBackButton() : Container()));
  }

  Widget _getBackButton() {
    return IconButton(
        icon: Icon(Icons.arrow_back),
        tooltip: trans('Back'),
        onPressed: () {
          AppNavigator.pop(context);
        });
  }

  Widget _getText(int index) {
    Widget text = Text(
      _titleLevels![index]?[1] ?? '',
      style: TextStyle(
        color: index == _max
            ? ThemeService.textSubColor
            : ThemeService.secondryColor,
      ),
    );

    if (index != _max) {
      return Row(children: <Widget>[
        text,
        SizedBox(width: 3),
        Text('/', style: TextStyle(color: ThemeService.textSubColor)),
        SizedBox(width: 3),
      ]);
    }
    return text;
  }
}
